@@ -6,13 +6,13 @@
 /* #undef SIGCXX_DISABLE_DEPRECATED */
 
 /* Major version number of sigc++. */
-#define SIGCXX_MAJOR_VERSION 2
+#define SIGCXX_MAJOR_VERSION 3
 
 /* Minor version number of sigc++. */
-#define SIGCXX_MINOR_VERSION 10
+#define SIGCXX_MINOR_VERSION 0
 
 /* Micro version number of sigc++. */
-#define SIGCXX_MICRO_VERSION 6
+#define SIGCXX_MICRO_VERSION 4
 
 /* Detect Win32 platform */
 #ifdef _WIN32
@@ -47,10 +47,6 @@
  */
 # pragma warning(disable:4251)
 
-# define SIGC_MSVC_TEMPLATE_SPECIALIZATION_OPERATOR_OVERLOAD 1
-# define SIGC_NEW_DELETE_IN_LIBRARY_ONLY 1 /* To keep ABI compatibility */
-# define SIGC_PRAGMA_PUSH_POP_MACRO 1
-
 #if (_MSC_VER < 1900) && !defined (noexcept)
 #define _ALLOW_KEYWORD_MACROS 1
 #define noexcept _NOEXCEPT
@@ -58,20 +54,6 @@
 
 #else /* SIGC_MSC */
 
-/* does the C++ compiler support the use of a particular specialization when
-   calling operator() template methods. */
-#define SIGC_GCC_TEMPLATE_SPECIALIZATION_OPERATOR_OVERLOAD
-
-/* Define if the non-standard Sun reverse_iterator must be used. */
-/* #undef SIGC_HAVE_SUN_REVERSE_ITERATOR */
-
-/* does the C++ compiler support the use of a particular specialization when
-   calling operator() template methods omitting the template keyword. */
-#define SIGC_MSVC_TEMPLATE_SPECIALIZATION_OPERATOR_OVERLOAD
-
-/* does the C++ preprocessor support pragma push_macro() and pop_macro(). */
-#define SIGC_PRAGMA_PUSH_POP_MACRO
-
 #endif /* !SIGC_MSC */
 
 #ifdef SIGC_DLL
